@@ -277,33 +277,15 @@ class RequestQueuer(object):
                     self.last_req[host] = time.time()
                     self.active_reqs[host] = self.active_reqs.get(host, 0) + 1
             if not dispatched_requests:
-                LOGGER.critical("Done with Check active. (1) Active: %s, Max Simul: %s, Pending: %s" % (
-                    self.getActive(),
-                    self.max_simul_reqs,
-                    self.getPending()))
                 return
-        LOGGER.critical("Done with Check active. (2) Active: %s, Max Simul: %s, Pending: %s" % (
-            self.getActive(),
-            self.max_simul_reqs,
-            self.getPending()))
-                            
+
     def _requestComplete(self, response, deferred, host):
-        LOGGER.critical("Request complete for %s. (2) Active: %s, Max Simul: %s, Pending: %s" % (
-            host,
-            self.getActive(),
-            self.max_simul_reqs,
-            self.getPending()))
         self.active_reqs[host] -= 1
         self._checkActive()
         deferred.callback(response)
         return None
 
-    def _requestError(self, error, deferred, host):
-        LOGGER.critical("Request error for %s. (2) Active: %s, Max Simul: %s, Pending: %s" % (
-            host,
-            self.getActive(),
-            self.max_simul_reqs,
-            self.getPending()))        
+    def _requestError(self, error, deferred, host):     
         self.active_reqs[host] -= 1
         self._checkActive()
         deferred.errback(error)
