@@ -331,7 +331,7 @@ class ExecutionServer(BaseServer):
             self.job_queue = filter(self.testJobByStart, self.job_queue)
         elif self.uuid_limits["start"] is not None and self.uuid_limits["end"] is not None:
             self.job_queue = filter(self.testJobByStartAndEnd, self.job_queue)
-        LOGGER.critical("Abandoned %s jobs that were out of range." % (job_queue_length - len(self.job_queue)))
+        LOGGER.info("Abandoned %s jobs that were out of range." % (job_queue_length - len(self.job_queue)))
         LOGGER.debug("Updated UUID limits to: %s" % self.uuid_limits)
     
     def _coordinateErrback(self, error):
@@ -474,7 +474,7 @@ class ExecutionServer(BaseServer):
         LOGGER.error("Unable to query SimpleDB.\n%s" % error)
         
     def _queryCallback(self, data):
-        LOGGER.critical("Fetched %s jobs." % len(data))
+        LOGGER.info("Fetched %s jobs." % len(data))
         self.querying_for_jobs = False
         # Iterate through the reservation data returned from SimpleDB
         for uuid in data:
@@ -547,13 +547,12 @@ class ExecutionServer(BaseServer):
     def reportJobSpeed(self):
         if self.query_start_time is not None and self.job_count > 0:
             seconds_per_job = (time.time() - self.query_start_time) / self.job_count
-            LOGGER.critical("Average execution time: %s, %s active." % (seconds_per_job, len(self.active_jobs)))
+            LOGGER.info("Average execution time: %s, %s active." % (seconds_per_job, len(self.active_jobs)))
         else:
-            LOGGER.critical("No average speed to report yet.")
+            LOGGER.info("No average speed to report yet.")
             
     def executeJobs(self, data=None):           
         while len(self.job_queue) > 0 and len(self.active_jobs) < self.simultaneous_jobs:
-            LOGGER.critical("EXECUTE JOBS LOOP") 
             job = self.job_queue.pop(0)
             exposed_function = job["exposed_function"]
             kwargs = job["kwargs"]
